@@ -5,20 +5,20 @@ A simple but non-restrictive abstraction of WSGI for end users.
 
 (See the docstrings of the various functions and classes.)
 
-Copyright (C) 2006 Luke Arno - http://lukearno.com/
+Copyright (C) 2006-2007 Luke Arno - http://lukearno.com/
 
-This program is free software; you can redistribute it and/or modify 
-it under the terms of the GNU General Public License as published by the 
-Free Software Foundation; either version 2 of the License, or (at your 
-option) any later version.
+This library is free software; you can redistribute it and/or
+modify it under the terms of the GNU Lesser General Public
+License as published by the Free Software Foundation; either
+version 2.1 of the License, or (at your option) any later version.
 
-This program is distributed in the hope that it will be useful, but 
-WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU 
-General Public License for more details.
+This library is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+Lesser General Public License for more details.
 
-You should have received a copy of the GNU General Public License
-along with this program; if not, write to:
+You should have received a copy of the GNU Lesser General Public
+License along with this library; if not, write to:
 
 The Free Software Foundation, Inc., 
 51 Franklin Street, Fifth Floor, 
@@ -69,14 +69,16 @@ class URI(object):
         """
         if path is None:
             path = self.path
-        app_uri = self.application_uri()
         if path[0:1] != '/':
-            app_uri = '/'.join((app_uri + self.path).split('/')[:-1])
+            uri = self.application_uri()
+            uri = '/'.join((uri + self.path).split('/')[:-1])
             while path[:3] == '../':
-                app_uri = '/'.join(app_uri.split('/')[:-1])
+                uri = '/'.join(uri.split('/')[:-1])
                 path = path[3:]
             path = '/' + path
-        uri = app_uri + urllib.quote(path)
+        else:
+            uri = self.server_uri()
+        uri += urllib.quote(path)
         if with_qs and self.query:
             uri += '?' + self.query
         return uri
